@@ -1,6 +1,6 @@
 package MARC::Moose::Lint::Processor;
 # ABSTRACT: Processor to lint a biblio records file
-$MARC::Moose::Lint::Processor::VERSION = '1.0.21';
+$MARC::Moose::Lint::Processor::VERSION = '1.0.22';
 use Moose;
 use Modern::Perl;
 use MARC::Moose::Reader::File::Iso2709;
@@ -9,7 +9,10 @@ use MARC::Moose::Lint::Checker;
 
 extends 'AnyEvent::Processor';
 
-has lint => (is => 'rw', isa => 'MARC::Moose::Lint::Checker');
+has lint => (
+    is => 'rw',
+    isa => 'MARC::Moose::Lint::Checker'
+);
 
 
 has file => (
@@ -112,11 +115,11 @@ MARC::Moose::Lint::Processor - Processor to lint a biblio records file
 
 =head1 VERSION
 
-version 1.0.21
+version 1.0.22
 
 =head1 ATTRIBUTES
 
-=head2 linter
+=head2 lint
 
 A L<MARC::Moose::Lint::Checker> to be used to validate biblio record.
 
